[FFmpeg-devel] [PATCH 07/10] spdif: fix occurrences of IEC958 where IEC 61937 is meant

Anssi Hannula anssi.hannula
Wed Dec 29 06:06:40 CET 2010


This format is actually IEC 61937. IEC958 is a lower level format and
IEC958 encapsulation is usually performed by the sound hardware instead.
---
 libavformat/spdif.h    |   42 +++++++++++++-------------
 libavformat/spdifdec.c |   26 ++++++++--------
 libavformat/spdifenc.c |   74 ++++++++++++++++++++++++------------------------
 3 files changed, 71 insertions(+), 71 deletions(-)

diff --git a/libavformat/spdif.h b/libavformat/spdif.h
index 252eda9..ac5be7c 100644
--- a/libavformat/spdif.h
+++ b/libavformat/spdif.h
@@ -25,27 +25,27 @@
 #define SYNCWORD2 0x4E1F
 #define BURST_HEADER_SIZE 0x8
 
-enum IEC958DataType {
-    IEC958_AC3                = 0x01,          ///< AC-3 data
-    IEC958_MPEG1_LAYER1       = 0x04,          ///< MPEG-1 layer 1
-    IEC958_MPEG1_LAYER23      = 0x05,          ///< MPEG-1 layer 2 or 3 data or MPEG-2 without extension
-    IEC958_MPEG2_EXT          = 0x06,          ///< MPEG-2 data with extension
-    IEC958_MPEG2_AAC          = 0x07,          ///< MPEG-2 AAC ADTS
-    IEC958_MPEG2_LAYER1_LSF   = 0x08,          ///< MPEG-2, layer-1 low sampling frequency
-    IEC958_MPEG2_LAYER2_LSF   = 0x09,          ///< MPEG-2, layer-2 low sampling frequency
-    IEC958_MPEG2_LAYER3_LSF   = 0x0A,          ///< MPEG-2, layer-3 low sampling frequency
-    IEC958_DTS1               = 0x0B,          ///< DTS type I   (512 samples)
-    IEC958_DTS2               = 0x0C,          ///< DTS type II  (1024 samples)
-    IEC958_DTS3               = 0x0D,          ///< DTS type III (2048 samples)
-    IEC958_ATRAC              = 0x0E,          ///< Atrac data
-    IEC958_ATRAC3             = 0x0F,          ///< Atrac 3 data
-    IEC958_ATRACX             = 0x10,          ///< Atrac 3 plus data
-    IEC958_DTSHD              = 0x11,          ///< DTS HD data
-    IEC958_WMAPRO             = 0x12,          ///< WMA 9 Professional data
-    IEC958_MPEG2_AAC_LSF_2048 = 0x13,          ///< MPEG-2 AAC ADTS half-rate low sampling frequency
-    IEC958_MPEG2_AAC_LSF_4096 = 0x13 | 0x20,   ///< MPEG-2 AAC ADTS quarter-rate low sampling frequency
-    IEC958_EAC3               = 0x15,          ///< E-AC-3 data
-    IEC958_TRUEHD             = 0x16,          ///< TrueHD data
+enum IEC61937DataType {
+    IEC61937_AC3                = 0x01,          ///< AC-3 data
+    IEC61937_MPEG1_LAYER1       = 0x04,          ///< MPEG-1 layer 1
+    IEC61937_MPEG1_LAYER23      = 0x05,          ///< MPEG-1 layer 2 or 3 data or MPEG-2 without extension
+    IEC61937_MPEG2_EXT          = 0x06,          ///< MPEG-2 data with extension
+    IEC61937_MPEG2_AAC          = 0x07,          ///< MPEG-2 AAC ADTS
+    IEC61937_MPEG2_LAYER1_LSF   = 0x08,          ///< MPEG-2, layer-1 low sampling frequency
+    IEC61937_MPEG2_LAYER2_LSF   = 0x09,          ///< MPEG-2, layer-2 low sampling frequency
+    IEC61937_MPEG2_LAYER3_LSF   = 0x0A,          ///< MPEG-2, layer-3 low sampling frequency
+    IEC61937_DTS1               = 0x0B,          ///< DTS type I   (512 samples)
+    IEC61937_DTS2               = 0x0C,          ///< DTS type II  (1024 samples)
+    IEC61937_DTS3               = 0x0D,          ///< DTS type III (2048 samples)
+    IEC61937_ATRAC              = 0x0E,          ///< Atrac data
+    IEC61937_ATRAC3             = 0x0F,          ///< Atrac 3 data
+    IEC61937_ATRACX             = 0x10,          ///< Atrac 3 plus data
+    IEC61937_DTSHD              = 0x11,          ///< DTS HD data
+    IEC61937_WMAPRO             = 0x12,          ///< WMA 9 Professional data
+    IEC61937_MPEG2_AAC_LSF_2048 = 0x13,          ///< MPEG-2 AAC ADTS half-rate low sampling frequency
+    IEC61937_MPEG2_AAC_LSF_4096 = 0x13 | 0x20,   ///< MPEG-2 AAC ADTS quarter-rate low sampling frequency
+    IEC61937_EAC3               = 0x15,          ///< E-AC-3 data
+    IEC61937_TRUEHD             = 0x16,          ///< TrueHD data
 };
 
 static const uint16_t spdif_mpeg_pkt_offset[2][3] = {
diff --git a/libavformat/spdifdec.c b/libavformat/spdifdec.c
index 81e94e7..05a9145 100644
--- a/libavformat/spdifdec.c
+++ b/libavformat/spdifdec.c
@@ -31,7 +31,7 @@
 #include "libavcodec/aacadtsdec.h"
 
 static int spdif_get_offset_and_codec(AVFormatContext *s,
-                                      enum IEC958DataType data_type,
+                                      enum IEC61937DataType data_type,
                                       const char *buf, int *offset,
                                       enum CodecID *codec)
 {
@@ -39,23 +39,23 @@ static int spdif_get_offset_and_codec(AVFormatContext *s,
     GetBitContext gbc;
 
     switch (data_type & 0xff) {
-    case IEC958_AC3:
+    case IEC61937_AC3:
         *offset = AC3_FRAME_SIZE << 2;
         *codec = CODEC_ID_AC3;
         break;
-    case IEC958_MPEG1_LAYER1:
+    case IEC61937_MPEG1_LAYER1:
         *offset = spdif_mpeg_pkt_offset[1][0];
         *codec = CODEC_ID_MP1;
         break;
-    case IEC958_MPEG1_LAYER23:
+    case IEC61937_MPEG1_LAYER23:
         *offset = spdif_mpeg_pkt_offset[1][0];
         *codec = CODEC_ID_MP3;
         break;
-    case IEC958_MPEG2_EXT:
+    case IEC61937_MPEG2_EXT:
         *offset = 4608;
         *codec = CODEC_ID_MP3;
         break;
-    case IEC958_MPEG2_AAC:
+    case IEC61937_MPEG2_AAC:
         init_get_bits(&gbc, buf, AAC_ADTS_HEADER_SIZE * 8);
         if (ff_aac_parse_header(&gbc, &aac_hdr)) {
             if (s) /* be silent during a probe */
@@ -65,27 +65,27 @@ static int spdif_get_offset_and_codec(AVFormatContext *s,
         *offset = aac_hdr.samples << 2;
         *codec = CODEC_ID_AAC;
         break;
-    case IEC958_MPEG2_LAYER1_LSF:
+    case IEC61937_MPEG2_LAYER1_LSF:
         *offset = spdif_mpeg_pkt_offset[0][0];
         *codec = CODEC_ID_MP1;
         break;
-    case IEC958_MPEG2_LAYER2_LSF:
+    case IEC61937_MPEG2_LAYER2_LSF:
         *offset = spdif_mpeg_pkt_offset[0][1];
         *codec = CODEC_ID_MP2;
         break;
-    case IEC958_MPEG2_LAYER3_LSF:
+    case IEC61937_MPEG2_LAYER3_LSF:
         *offset = spdif_mpeg_pkt_offset[0][2];
         *codec = CODEC_ID_MP3;
         break;
-    case IEC958_DTS1:
+    case IEC61937_DTS1:
         *offset = 2048;
         *codec = CODEC_ID_DTS;
         break;
-    case IEC958_DTS2:
+    case IEC61937_DTS2:
         *offset = 4096;
         *codec = CODEC_ID_DTS;
         break;
-    case IEC958_DTS3:
+    case IEC61937_DTS3:
         *offset = 8192;
         *codec = CODEC_ID_DTS;
         break;
@@ -164,7 +164,7 @@ static int spdif_read_header(AVFormatContext *s, AVFormatParameters *ap)
 static int spdif_read_packet(AVFormatContext *s, AVPacket *pkt)
 {
     ByteIOContext *pb = s->pb;
-    enum IEC958DataType data_type;
+    enum IEC61937DataType data_type;
     enum CodecID codec_id;
     uint32_t state = 0;
     int pkt_size_bits, offset, ret;
diff --git a/libavformat/spdifenc.c b/libavformat/spdifenc.c
index 870a543..b41e246 100644
--- a/libavformat/spdifenc.c
+++ b/libavformat/spdifenc.c
@@ -1,5 +1,5 @@
 /*
- * IEC958 muxer
+ * IEC 61937 muxer
  * Copyright (c) 2009 Bartlomiej Wolowiec
  * Copyright (c) 2010 Anssi Hannula
  * Copyright (c) 2010 Carl Eugen Hoyos
@@ -31,8 +31,8 @@
 
 /*
  * Terminology used in specification:
  * data-burst - IEC958 frame, contains header and encapsuled frame
  * burst-preambule - IEC958 frame header, contains 16-bits words named Pa, Pb, Pc and Pd
  * burst-payload - encapsuled frame
  * Pa, Pb - syncword - 0xF872, 0x4E1F
  * Pc - burst-info, contains data-type (bits 0-6), error flag (bit 7), data-type-dependent info (bits 8-12)
@@ -40,7 +40,7 @@
  * data-type - determines type of encapsuled frames
  * Pd - length code (number of bits or bytes of encapsuled frame - according to data_type)
  *
- * IEC958 frames at normal usage start every specific count of bytes,
+ * IEC 61937 frames at normal usage start every specific count of bytes,
  *      dependent from data-type (spaces between packets are filled by zeros)
  */
 
@@ -52,9 +52,9 @@
 #include "libavcodec/aacadtsdec.h"
 #include "libavutil/opt.h"
 
-typedef struct IEC958Context {
+typedef struct IEC61937Context {
     const AVClass *av_class;
-    enum IEC958DataType data_type;  ///< burst info - reference to type of payload of the data-burst
+    enum IEC61937DataType data_type;///< burst info - reference to type of payload of the data-burst
     int length_code;                ///< length code in bits or bytes, depending on data type
     int pkt_offset;                 ///< data burst repetition period in bytes
     uint8_t *buffer;                ///< allocated buffer, used for swap bytes
@@ -82,13 +82,13 @@ typedef struct IEC958Context {
     /// function, which generates codec dependent header information.
     /// Sets data_type and pkt_offset, and length_code, out_bytes, out_buf if necessary
     int (*header_info) (AVFormatContext *s, AVPacket *pkt);
-} IEC958Context;
+} IEC61937Context;
 
 static const AVOption options[] = {
-{ "spdif_flags", "IEC 61937 encapsulation flags", offsetof(IEC958Context, spdif_flags), FF_OPT_TYPE_FLAGS, 0, 0, INT_MAX, AV_OPT_FLAG_ENCODING_PARAM, "spdif_flags" },
+{ "spdif_flags", "IEC 61937 encapsulation flags", offsetof(IEC61937Context, spdif_flags), FF_OPT_TYPE_FLAGS, 0, 0, INT_MAX, AV_OPT_FLAG_ENCODING_PARAM, "spdif_flags" },
 { "be", "output in big-endian format (for use as s16be)", 0, FF_OPT_TYPE_CONST, SPDIF_FLAG_BIGENDIAN, 0, INT_MAX, AV_OPT_FLAG_ENCODING_PARAM, "spdif_flags" },
-{ "dtshd_rate", "mux complete DTS frames in HD mode at the specified IEC958 rate (in Hz, default 0=disabled)", offsetof(IEC958Context, dtshd_rate), FF_OPT_TYPE_INT, 0, 0, 768000, AV_OPT_FLAG_ENCODING_PARAM },
-{ "dtshd_fallback_time", "min secs to strip HD for after an overflow (-1: till the end)", offsetof(IEC958Context, dtshd_fallback), FF_OPT_TYPE_INT, 60, -1, INT_MAX, AV_OPT_FLAG_ENCODING_PARAM },
+{ "dtshd_rate", "mux complete DTS frames in HD mode at the specified IEC958 rate (in Hz, default 0=disabled)", offsetof(IEC61937Context, dtshd_rate), FF_OPT_TYPE_INT, 0, 0, 768000, AV_OPT_FLAG_ENCODING_PARAM },
+{ "dtshd_fallback_time", "min secs to strip HD for after an overflow (-1: till the end)", offsetof(IEC61937Context, dtshd_fallback), FF_OPT_TYPE_INT, 60, -1, INT_MAX, AV_OPT_FLAG_ENCODING_PARAM },
 { NULL },
 };
 
@@ -96,17 +96,17 @@ static const AVClass class = { "spdif", av_default_item_name, options, LIBAVUTIL
 
 static int spdif_header_ac3(AVFormatContext *s, AVPacket *pkt)
 {
-    IEC958Context *ctx = s->priv_data;
+    IEC61937Context *ctx = s->priv_data;
     int bitstream_mode = pkt->data[6] & 0x7;
 
-    ctx->data_type  = IEC958_AC3 | (bitstream_mode << 8);
+    ctx->data_type  = IEC61937_AC3 | (bitstream_mode << 8);
     ctx->pkt_offset = AC3_FRAME_SIZE << 2;
     return 0;
 }
 
 static int spdif_header_eac3(AVFormatContext *s, AVPacket *pkt)
 {
-    IEC958Context *ctx = s->priv_data;
+    IEC61937Context *ctx = s->priv_data;
     static const uint8_t eac3_repeat[4] = {6, 3, 2, 1};
     int repeat = 1;
 
@@ -124,7 +124,7 @@ static int spdif_header_eac3(AVFormatContext *s, AVPacket *pkt)
         ctx->pkt_offset = 0;
         return 0;
     }
-    ctx->data_type   = IEC958_EAC3;
+    ctx->data_type   = IEC61937_EAC3;
     ctx->pkt_offset  = 24576;
     ctx->out_buf     = ctx->hd_buf;
     ctx->out_bytes   = ctx->hd_buf_filled;
@@ -167,7 +167,7 @@ static int spdif_dts4_subtype(int period)
 static int spdif_header_dts4(AVFormatContext *s, AVPacket *pkt, int core_size,
                              int sample_rate, int blocks)
 {
-    IEC958Context *ctx = s->priv_data;
+    IEC61937Context *ctx = s->priv_data;
     const char dtshd_start_code[10] = { 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0xfe };
     int pkt_size = pkt->size;
     int period;
@@ -197,7 +197,7 @@ static int spdif_header_dts4(AVFormatContext *s, AVPacket *pkt, int core_size,
     /* set pkt_offset and DTS IV subtype according to the requested output
      * rate */
     ctx->pkt_offset = period * 4;
-    ctx->data_type = IEC958_DTSHD | subtype << 8;
+    ctx->data_type = IEC61937_DTSHD | subtype << 8;
 
     /* If the bitrate is too high for transmitting at the selected
      * repetition period setting, strip DTS-HD until a good amount
@@ -239,7 +239,7 @@ static int spdif_header_dts4(AVFormatContext *s, AVPacket *pkt, int core_size,
 
 static int spdif_header_dts(AVFormatContext *s, AVPacket *pkt)
 {
-    IEC958Context *ctx = s->priv_data;
+    IEC61937Context *ctx = s->priv_data;
     uint32_t syncword_dts = AV_RB32(pkt->data);
     int blocks;
     int sample_rate = 0;
@@ -284,9 +284,9 @@ static int spdif_header_dts(AVFormatContext *s, AVPacket *pkt)
         return spdif_header_dts4(s, pkt, core_size, sample_rate, blocks);
 
     switch (blocks) {
-    case  512 >> 5: ctx->data_type = IEC958_DTS1; break;
-    case 1024 >> 5: ctx->data_type = IEC958_DTS2; break;
-    case 2048 >> 5: ctx->data_type = IEC958_DTS3; break;
+    case  512 >> 5: ctx->data_type = IEC61937_DTS1; break;
+    case 1024 >> 5: ctx->data_type = IEC61937_DTS2; break;
+    case 2048 >> 5: ctx->data_type = IEC61937_DTS3; break;
     default:
         av_log(s, AV_LOG_ERROR, "%i samples in DTS frame not supported\n",
                blocks << 5);
@@ -314,15 +314,15 @@ static int spdif_header_dts(AVFormatContext *s, AVPacket *pkt)
     return 0;
 }
 
-static const enum IEC958DataType mpeg_data_type[2][3] = {
+static const enum IEC61937DataType mpeg_data_type[2][3] = {
     //     LAYER1                      LAYER2                  LAYER3
-    { IEC958_MPEG2_LAYER1_LSF, IEC958_MPEG2_LAYER2_LSF, IEC958_MPEG2_LAYER3_LSF },  //MPEG2 LSF
-    { IEC958_MPEG1_LAYER1,     IEC958_MPEG1_LAYER23,    IEC958_MPEG1_LAYER23 },     //MPEG1
+    { IEC61937_MPEG2_LAYER1_LSF, IEC61937_MPEG2_LAYER2_LSF, IEC61937_MPEG2_LAYER3_LSF },  //MPEG2 LSF
+    { IEC61937_MPEG1_LAYER1,     IEC61937_MPEG1_LAYER23,    IEC61937_MPEG1_LAYER23 },     //MPEG1
 };
 
 static int spdif_header_mpeg(AVFormatContext *s, AVPacket *pkt)
 {
-    IEC958Context *ctx = s->priv_data;
+    IEC61937Context *ctx = s->priv_data;
     int version =      (pkt->data[1] >> 3) & 3;
     int layer   = 3 - ((pkt->data[1] >> 1) & 3);
     int extension = pkt->data[2] & 1;
@@ -333,7 +333,7 @@ static int spdif_header_mpeg(AVFormatContext *s, AVPacket *pkt)
     }
     av_log(s, AV_LOG_DEBUG, "version: %i layer: %i extension: %i\n", version, layer, extension);
     if (version == 2 && extension) {
-        ctx->data_type  = IEC958_MPEG2_EXT;
+        ctx->data_type  = IEC61937_MPEG2_EXT;
         ctx->pkt_offset = 4608;
     } else {
         ctx->data_type  = mpeg_data_type [version & 1][layer];
@@ -345,7 +345,7 @@ static int spdif_header_mpeg(AVFormatContext *s, AVPacket *pkt)
 
 static int spdif_header_aac(AVFormatContext *s, AVPacket *pkt)
 {
-    IEC958Context *ctx = s->priv_data;
+    IEC61937Context *ctx = s->priv_data;
     AACADTSHeaderInfo hdr;
     GetBitContext gbc;
     int ret;
@@ -360,13 +360,13 @@ static int spdif_header_aac(AVFormatContext *s, AVPacket *pkt)
     ctx->pkt_offset = hdr.samples << 2;
     switch (hdr.num_aac_frames) {
     case 1:
-        ctx->data_type = IEC958_MPEG2_AAC;
+        ctx->data_type = IEC61937_MPEG2_AAC;
         break;
     case 2:
-        ctx->data_type = IEC958_MPEG2_AAC_LSF_2048;
+        ctx->data_type = IEC61937_MPEG2_AAC_LSF_2048;
         break;
     case 4:
-        ctx->data_type = IEC958_MPEG2_AAC_LSF_4096;
+        ctx->data_type = IEC61937_MPEG2_AAC_LSF_4096;
         break;
     default:
         av_log(s, AV_LOG_ERROR, "%i samples in AAC frame not supported\n",
@@ -393,7 +393,7 @@ static int spdif_header_aac(AVFormatContext *s, AVPacket *pkt)
 
 static int spdif_header_truehd(AVFormatContext *s, AVPacket *pkt)
 {
-    IEC958Context *ctx = s->priv_data;
+    IEC61937Context *ctx = s->priv_data;
     int mat_code_length = 0;
     const char mat_end_code[16] = { 0xC3, 0xC2, 0xC0, 0xC4, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x97, 0x11 };
 
@@ -429,7 +429,7 @@ static int spdif_header_truehd(AVFormatContext *s, AVPacket *pkt)
     memcpy(&ctx->hd_buf[MAT_FRAME_SIZE - sizeof(mat_end_code)], mat_end_code, sizeof(mat_end_code));
     ctx->hd_buf_count = 0;
 
-    ctx->data_type   = IEC958_TRUEHD;
+    ctx->data_type   = IEC61937_TRUEHD;
     ctx->pkt_offset  = 61440;
     ctx->out_buf     = ctx->hd_buf;
     ctx->out_bytes   = MAT_FRAME_SIZE;
@@ -439,7 +439,7 @@ static int spdif_header_truehd(AVFormatContext *s, AVPacket *pkt)
 
 static int spdif_write_header(AVFormatContext *s)
 {
-    IEC958Context *ctx = s->priv_data;
+    IEC61937Context *ctx = s->priv_data;
 
     switch (s->streams[0]->codec->codec_id) {
     case CODEC_ID_AC3:
@@ -474,7 +474,7 @@ static int spdif_write_header(AVFormatContext *s)
 
 static int spdif_write_trailer(AVFormatContext *s)
 {
-    IEC958Context *ctx = s->priv_data;
+    IEC61937Context *ctx = s->priv_data;
     av_freep(&ctx->buffer);
     av_freep(&ctx->hd_buf);
     return 0;
@@ -482,7 +482,7 @@ static int spdif_write_trailer(AVFormatContext *s)
 
 static void spdif_put_16(struct AVFormatContext *s, unsigned int val)
 {
-    IEC958Context *ctx = s->priv_data;
+    IEC61937Context *ctx = s->priv_data;
     if (ctx->spdif_flags & SPDIF_FLAG_BIGENDIAN)
         put_be16(s->pb, val);
     else
@@ -491,7 +491,7 @@ static void spdif_put_16(struct AVFormatContext *s, unsigned int val)
 
 static int spdif_write_packet(struct AVFormatContext *s, AVPacket *pkt)
 {
-    IEC958Context *ctx = s->priv_data;
+    IEC61937Context *ctx = s->priv_data;
     int ret, padding;
 
     ctx->out_buf = pkt->data;
@@ -545,10 +545,10 @@ static int spdif_write_packet(struct AVFormatContext *s, AVPacket *pkt)
 
 AVOutputFormat spdif_muxer = {
     "spdif",
-    NULL_IF_CONFIG_SMALL("IEC958 - S/PDIF (IEC-61937)"),
+    NULL_IF_CONFIG_SMALL("IEC 61937 (used on S/PDIF - IEC958)"),
     NULL,
     "spdif",
-    sizeof(IEC958Context),
+    sizeof(IEC61937Context),
     CODEC_ID_AC3,
     CODEC_ID_NONE,
     spdif_write_header,
@@ -31,8 +31,8 @@
 /*
  * Terminology used in specification:
- * data-burst - IEC958 frame, contains header and encapsuled frame
- * burst-preambule - IEC958 frame header, contains 16-bits words named Pa, Pb, Pc and Pd
+ * data-burst - IEC61937 frame, contains header and encapsuled frame
+ * burst-preambule - IEC61937 frame header, contains 16-bits words named Pa, Pb, Pc and Pd
  * burst-payload - encapsuled frame
  * Pa, Pb - syncword - 0xF872, 0x4E1F
-- 
1.7.3




More information about the ffmpeg-devel mailing list